/*
****************************************************************************
****************************************************************************
**                                                                        **
**                XXXX     X    X         X XXXXXX X                      **
**               X    X   X X   X    X    X X      X   X                  **
**               X       X   X  X   X X   X X      X  X                   **
**               X   XX XXXXXXX X  X   X  X XXXX   X X                    **
**               X    X X     X X X     X X X      XX                     **
**               X    X X     X XX       XX X      X                      **
**                XXXX  X     X X         X XXXXXX XXXXXX                 **
**                                                                        **
**                           BIAYSTOK 2014                               **
**                                                                        **
**                         Home Control System                            **
**                                                                        **
**                              HC_TMPS1                                  **
**                      Wersja z dnia : 2017.12.09                        **
**                     Napisal : Andrzej Pawluczuk                        **
**                                                                        **
****************************************************************************
****************************************************************************
*/


#include "tmps1eeprom_ds1820.h"
#include <inttypes.h>
#include <avr/pgmspace.h>

#define null 0

EEPROMBlockDataRecT EEBlock ;


static uint8_t MyDefaultID [ ] PROGMEM               = "TMPS1" ;
static uint8_t SuperiorDeviceID [ ] PROGMEM          = "" ;
static uint8_t GlobalBaseDeviceID [ ] PROGMEM        = "" ;
static uint8_t DisplayDeviceID [ ] PROGMEM           = "" ;
static uint8_t MeansParamName [ ] PROGMEM            = "" ;
static uint8_t MotorControlDeviceID [ ] PROGMEM      = "" ;
#define DefaultAutoMode                              0



static void EEPROMClearBlock ( void *   Destination ,
                               uint16_t Size )
{
  uint16_t Loop ;
  uint8_t * Dst ;
  /*----------------------------------------------------------------*/
  Dst = ( uint8_t * ) Destination ;
  for ( Loop = 0 ; Loop < Size ; Loop ++ )
    * Dst ++ = null ;
} /* EEPROMClearBlock */


static void SetIDFlash ( uint8_t * DeviceID , 
                         uint16_t  String )
{
  uint8_t Data ;
  uint8_t Loop ;
  uint8_t * DestCh ;
  /*----------------------------------------------------------------*/
  DestCh = DeviceID ;
  for ( Loop = 0 ; Loop <= DeviceIDSize ; Loop ++ )
    * DestCh ++ = null ;
  DestCh = DeviceID ;
  for ( Loop = 0 ; Loop < DeviceIDSize ; Loop ++ )
  {
    Data = pgm_read_byte_near ( String ++ ) ;
    if ( Data )
      * DestCh ++ = Data ;
    else
      break ;
  } /* for */ ;
} /* SetIDFlash */


static void SetParamFlash ( uint8_t * ParamID , 
                            uint16_t  String )
{
  uint8_t Data ;
  uint8_t Loop ;
  uint8_t * DestCh ;
  /*----------------------------------------------------------------*/
  DestCh = ParamID ;
  for ( Loop = 0 ; Loop <= ParamNameSize ; Loop ++ )
    * DestCh ++ = null ;
  DestCh = ParamID ;
  for ( Loop = 0 ; Loop < DeviceIDSize ; Loop ++ )
  {
    Data = pgm_read_byte_near ( String ++ ) ;
    if ( Data )
      * DestCh ++ = Data ;
    else
      break ;
  } /* for */ ;
} /* SetParamFlash */


void SetDefaultEEBlock ( void )
{
  /*----------------------------------------------------------------*/
  EEPROMClearBlock ( & EEBlock , sizeof ( EEPROMBlockDataRecT ) ) ;
  EEBlock . EEBlockMetric = StandardSygnature ;
  SetIDFlash ( EEBlock . MyDeviceID , ( uint16_t ) MyDefaultID ) ;
  SetIDFlash ( EEBlock . EventDestinDeviceID [ 0 ] , ( uint16_t ) SuperiorDeviceID ) ;
  SetIDFlash ( EEBlock . EventDestinDeviceID [ 1 ] , ( uint16_t ) GlobalBaseDeviceID ) ;
  SetIDFlash ( EEBlock . EventDestinDeviceID [ 2 ] , ( uint16_t ) DisplayDeviceID ) ;
  SetIDFlash ( EEBlock . EventDestinDeviceID [ 3 ] , ( uint16_t ) MotorControlDeviceID ) ;
  SetParamFlash ( EEBlock . ParamName , ( uint16_t ) MeansParamName ) ;
  EEBlock . Password [ 0 ] = 'M' ;
  EEBlock . Password [ 1 ] = 'A' ;
  EEBlock . Password [ 2 ] = 'G' ;
  EEBlock . Password [ 3 ] = 'I' ;
  EEBlock . Password [ 4 ] = 'C' ;
  EEBlock . Password [ 5 ] = null ;
  EEBlock . AutoMeansTimeInterval = 10 ;
  EEBlock . AutoMode = DefaultAutoMode ;
  EEBlock . CRCValue = 0 ;
} /* SetDefaultEEBlock */


